/*****************************************************************************
* | File      	:	EPD_4in2.c
* | Author      :   Waveshare team
* | Function    :   Electronic paper driver
* | Info        :
*----------------
* |	This version:   V1.0
* | Date        :   2024-12-26
* | Info        :
*****************************************************************************
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documnetation files(the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to  whom the Software is
# furished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS OR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
******************************************************************************/
#include "EPD_4in2.h"

/******************************************************************************
function :	Wait until the busy_pin goes HIGH
parameter:
******************************************************************************/
static void ReadBusy(void)
{
    printf("e-Paper busy\r\n");
	do{
		DEV_Delay_ms(100);  
	}while(EPD_ReadBusy());   
	DEV_Delay_ms(5);      
    printf("e-Paper busy release\r\n");
}
/******************************************************************************
function :	Turn On Display
parameter:
******************************************************************************/
static void EPD_4IN2_V2_TurnOnDisplay(void)
{	
    printf("Refresh e-paper/r/n");
    EPD_Send_1(0x22,0xf7);
    EPD_Send_0(0x20);			//DISPLAY REFRESH
    DEV_Delay_ms(100);	        //!!!The delay here is necessary, 200uS at least!!!
    ReadBusy();
}

/******************************************************************************
function :	Initialize the e-Paper register
parameter:
******************************************************************************/
UBYTE EPD_4IN2_V2_Init(void)
{
/*
    Send data and commands separately, send commands and data together, choose one from the two
*/    

//    EPD_Reset();
//    ReadBusy();   
//    EPD_SendCommand(0x12);
//    ReadBusy();  

//    EPD_SendCommand(0x21);
//    EPD_SendData(0x40);		
//    EPD_SendData(0x00);		

//    EPD_SendCommand(0x3C);
//    EPD_SendData(0x05);

//    EPD_SendCommand(0x11);
//    EPD_SendData(0x03);

//    EPD_SendCommand(0x44);
//    EPD_SendData(0x00);
//    EPD_SendData(0x31);

//    EPD_SendCommand(0x45);
//    EPD_SendData(0x00);
//    EPD_SendData(0x00);
//    EPD_SendData(0x2B);
//    EPD_SendData(0x01);

//    EPD_SendCommand(0x4E);
//    EPD_SendData(0x00);

//    EPD_SendCommand(0x4F);
//    EPD_SendData(0x00);
//    EPD_SendData(0x00);
//    ReadBusy(); 
  

    
    EPD_Reset();
    ReadBusy();   
    EPD_Send_0(0x12);
    ReadBusy();
    EPD_Send_2(0x21,0x40,0x00);
    EPD_Send_1(0x3C,0x05);
    EPD_Send_1(0x11,0x03);
    EPD_Send_2(0x44,0x00,0x31);
    EPD_Send_4(0x45,0x00,0x00,0x2B,0x01);
    EPD_Send_1(0x4E,0x00);
    EPD_Send_2(0x4F,0x00,0x00);
    ReadBusy();  
    
    return 0;
}
/******************************************************************************
function :	Sends the image buffer in RAM to e-Paper and displays
parameter:
******************************************************************************/

void EPD_4IN2_V2_Clear(void)
{
    UDOUBLE Width, Height;
    Width =(EPD_4IN2_V2_WIDTH % 8 == 0)?(EPD_4IN2_V2_WIDTH / 8 ):(EPD_4IN2_V2_WIDTH / 8 + 1);
    Height = EPD_4IN2_V2_HEIGHT;

    UDOUBLE freq = (Width * Height % 250 == 0) ? (Width * Height / 250) : (Width * Height / 250 + 1);
	UBYTE len = (Width * Height%250 == 0) ? 250 : (Width * Height % 250);
    
    UBYTE buf[250];
    for(UDOUBLE i = 0; i < 250; i++)
    {
        buf[i] = 0x00;
    }
   
    EPD_SendCommand(0x24);
    for(UDOUBLE i = 0; i < freq - 1; i++)
    {
        EPD_IMG(buf, 250);
    }
    EPD_IMG(buf, len);
    
    EPD_4IN2_V2_TurnOnDisplay();
}

void EPD_4IN2_V2_Display(UWORD freq, UBYTE *buf)
{
    if(freq == 0)
        EPD_SendCommand(0x24);
    EPD_IMG(buf, 250);
    if(freq == 59)
        EPD_4IN2_V2_TurnOnDisplay();
}

/******************************************************************************
function :	Enter sleep mode
parameter:
******************************************************************************/
void EPD_4IN2_V2_Sleep(void)
{
    EPD_SendCommand(0x10);  	//deep sleep
    EPD_SendData(0x01);
}
