/*****************************************************************************
* | File      	:	EPD_7in5.c
* | Author      :   Waveshare team
* | Function    :   Electronic paper driver
* | Info        :
*----------------
* |	This version:   V1.0
* | Date        :   2024-12-10
* | Info        :
*****************************************************************************
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documnetation files(the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to  whom the Software is
# furished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS OR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
******************************************************************************/
#include "EPD_7in5.h"

/******************************************************************************
function :	Wait until the busy_pin goes LOW
parameter:
******************************************************************************/
static void EPD_WaitUntilIdle(void)
{
    printf("e-Paper busy\r\n");
	do{
		DEV_Delay_ms(100);  
	}while(!EPD_ReadBusy());   
	DEV_Delay_ms(5);      
    printf("e-Paper busy release\r\n");
}
/******************************************************************************
function :	Turn On Display
parameter:
******************************************************************************/
static void EPD_7IN5_V2_TurnOnDisplay(void)
{	
    printf("Refresh e-paper/r/n");
    EPD_SendCommand(0x12);			//DISPLAY REFRESH
    DEV_Delay_ms(100);	        //!!!The delay here is necessary, 200uS at least!!!
    EPD_WaitUntilIdle();
}

/******************************************************************************
function :	Initialize the e-Paper register
parameter:
******************************************************************************/
UBYTE EPD_7IN5_V2_Init(void)
{
/*
    Send data and commands separately, send commands and data together, choose one from the two
*/

//    EPD_Reset();
//    EPD_SendCommand(0x01);
//    EPD_SendData(0x07);
//    EPD_SendData(0x07);
//    EPD_SendData(0x3f);
//    EPD_SendData(0x3f);

//    EPD_SendCommand(0x06);
//    EPD_SendData(0x17);
//    EPD_SendData(0x17);
//    EPD_SendData(0x28);
//    EPD_SendData(0x17);

//    EPD_SendCommand(0x04);
//    DEV_Delay_ms(100);
//    EPD_WaitUntilIdle();

//    EPD_SendCommand(0X00);
//    EPD_SendData(0x1F);

//    EPD_SendCommand(0x61);		
//    EPD_SendData(0x03);
//    EPD_SendData(0x20);
//    EPD_SendData(0x01);
//    EPD_SendData(0xE0);  

//    EPD_SendCommand(0X15);		
//    EPD_SendData(0x00);		

//    EPD_SendCommand(0X50);			
//    EPD_SendData(0x10);
//    EPD_SendData(0x07);

//    EPD_SendCommand(0X60);
//    EPD_SendData(0x22);

    EPD_Reset();
    EPD_Send_4(0x01,0x07,0x07,0x3F,0x3F);
    EPD_Send_4(0x06,0x17,0x17,0x28,0x17);
    EPD_Send_0(0x04);
    EPD_WaitUntilIdle();
    EPD_Send_1(0x00,0x13);
    EPD_Send_4(0x61,0x03,0x20,0x01,0xE0);
    EPD_Send_1(0x15,0x00);
    EPD_Send_2(0x50,0x10,0x07);
    EPD_Send_1(0x60,0x22);
    
    
    return 0;
}
/******************************************************************************
function :	Sends the image buffer in RAM to e-Paper and displays
parameter:
******************************************************************************/

void EPD_7IN5_V2_Clear(void)
{
    UDOUBLE Width, Height;
    Width =(EPD_7IN5_V2_WIDTH % 8 == 0)?(EPD_7IN5_V2_WIDTH / 8 ):(EPD_7IN5_V2_WIDTH / 8 + 1);
    Height = EPD_7IN5_V2_HEIGHT;

    UDOUBLE freq = (EPD_7IN5_V2_WIDTH * EPD_7IN5_V2_HEIGHT % 250 == 0) ? (EPD_7IN5_V2_WIDTH * EPD_7IN5_V2_HEIGHT / 250) : (EPD_7IN5_V2_WIDTH * EPD_7IN5_V2_HEIGHT / 250 + 1);
	UBYTE len = (EPD_7IN5_V2_WIDTH * EPD_7IN5_V2_HEIGHT%250 == 0) ? 250 : (EPD_7IN5_V2_WIDTH * EPD_7IN5_V2_HEIGHT % 250);
    
    UBYTE buf[250];
    for(UDOUBLE i = 0; i < 250; i++)
    {
        buf[i] = 0x00;
    }
   
    EPD_SendCommand(0x13);
    for(UDOUBLE i = 0; i < freq - 1; i++)
    {
        EPD_IMG(buf, 250);
    }
    EPD_IMG(buf, len);
    
    EPD_7IN5_V2_TurnOnDisplay();
}

void EPD_7IN5_V2_Display(UWORD freq, UBYTE *buf)
{
    if(freq == 0)
        EPD_SendCommand(0x13);
    EPD_IMG(buf, 250);
    if(freq == 191)
        EPD_7IN5_V2_TurnOnDisplay();
}

/******************************************************************************
function :	Enter sleep mode
parameter:
******************************************************************************/
void EPD_7IN5_V2_Sleep(void)
{
    EPD_SendCommand(0x50);  	
    EPD_SendData(0XF7);
    EPD_SendCommand(0X02);  	//power off
    EPD_WaitUntilIdle();
    EPD_SendCommand(0X07);  	//deep sleep
    EPD_SendData(0xA5);
}
